
### Binaries #######################################################

CC_PATH    := /usr/bin

CC         := g++

LD_SHARED  := $(CC) -shared

LD_LNK     := ar -cr

RANLIB     := 

LD         := $(CC)

FLEX       := flex
BISON      := bison 

SUB_MAKE   := make

LINK       := ln -s

SED        := sed

### Patterns #########################################################

ifeq ($(OS_BASE), cygwin)
ifneq ($(DBGCMDGOAL),)
$(warning Detected OPT)
DEBUG_CHAR:=
else
$(warning Detected DBG)
DEBUG_CHAR:=D
endif
endif

COMPILER_LOGO        := 
PEDANTIC_ERRORS      := 0

SO_PRAEFIX           := lib
SO_SEARCH_SUFFIX     := .so
SO_SUFFIX            := $(DEBUG_CHAR).so
LIB_SEARCH_SUFFIX    := .a
LIB_SUFFIX           := $(DEBUG_CHAR).a

LNK_LIB_SUFFIX       := $(DEBUG_CHAR)Lnk.a

OBJ_SUFFIX           := .o
EXE_SUFFIX           := 

LIB_ARCH             :=

OS_BASE              := linux-gnu
OS_BUILD_BASE        := i686-pc-linux-gnu
OS_CMPLR             := g++
OS_CMPLR_DEF         := g++



LIBDIR_BASE          := lib
OBJDIR_BASE          := obj
EXEDIR_BASE          := exe

TEST_SRC_PATTERN     := test%.cpp

INC_OPTION           := -I

MAK_SUFFIX           := .mk
DEP_SUFFIX           := .d

INCL_$(OS_BASE)      :=
INCL_EXP_$(OS_BASE)  :=
LIBS_$(OS_BASE)      :=
OSG_LIB_EXT          := 

CONFIGURED_QT           :=0
CONFIGURED_QT4          :=0
CONFIGURED_GLUT         :=1
CONFIGURED_STLPORT      :=0
CONFIGURED_GLUT         :=1
CONFIGURED_JPG          :=0
CONFIGURED_JASPER       :=0
CONFIGURED_TIF          :=0
CONFIGURED_PNG          :=1
CONFIGURED_IMF          :=0
CONFIGURED_MNG          :=0
CONFIGURED_FREETYPE     :=0
CONFIGURED_TEXT         :=0
CONFIGURED_PACKAGE_DEFS := -DOSG_WITH_GLUT -DOSG_WITH_PNG

CONFIGURED_GVBETA       :=0



LINKER_INIT_FLAG     := -Wl,-Bsymbolic -Wl,-init 

LIBPATH_OPTION       := -L
LIBLNK_OPTION        := -l

OBJ_OPTION           := -o

NO_STDINC_DEP_OPTION := -Y

COMPONLY_OPTION      := -c

DEPEND_OPTION        := -M

LD_OUTOPT            := -o

LNK_LD_OUTOPT        :=

DIR_SEP              := /

II_FILESDIR          := 

### Defines #######################################################

ifeq ($(CONFIGURED_GVBETA),1)
DEF_GVBETA := -DOSG_GV_BETA
else
DEF_GVBETA :=
endif

# For QT
DEP_PLATTFORMDEF =  -DQT_NO_XINERAMA -DQT_NO_XRENDER -DQT_NO_XFTFREETYPE 	\
					-DQT_NO_XKB -DQT_NO_SM_SUPPORT -DQT_NO_IMAGEIO_MNG		\
					-DQT_NO_IMAGEIO_JPEG -DQT_NO_STYLE_AQUA 				\
					-DQT_NO_STYLE_MAC -DQT_NO_STYLE_INTERLACE 				\
					-DQT_NO_STYLE_COMPACT

SOURCE_DEFINES   = -D_GNU_SOURCE -DQT_CLEAN_NAMESPACE \
                   $(CONFIGURED_PACKAGE_DEFS)
#-DMNG_LIB -DPNG_LIB
#-D__STL_USE_NEW_IOSTREAMS

SYSTEM_DEFINES   = -D_OSG_HAVE_CONFIGURED_H_    \
                   $(DEF_GVBETA)


### Warnings #######################################################

WARNINGS	   	:= -Wall -W   -Wpointer-arith 			        \
				   -Wcast-align   -Wconversion   	\
				   -Winline 

#-Wshadow
#				   -Wmissing-declarations -Wmissing-noreturn    \

WARNINGS_C_OFF	:= # -woff 835

# 1110 : statement is unreachable
# 1174 : Variable declared but never referenced
# 1375 : Base class Destructor not virtual
# 1376 : class has no accessible constructors
# 1424 : The template parameter is not used in declaring the argument types
# 1682 : overloaded virtual function is only partially overridden
# rubens
# warning(3322): omission of explicit type is nonstandard ("int" assumed)

WARNINGS_CPP_OFF := -Wno-unused -Wno-long-long

# -Wcast-qual  (removed from default because of qt2.2
# -Wno-reorder (removed from default because of the generated base fc's

ifeq ($(PEDANTIC_ERRORS),1)
WARNINGS         := $(WARNINGS) -Wsign-compare -Wcast-qual -Wreorder
else
WARNINGS_CPP_OFF := $(WARNINGS_CPP_OFF) -Wno-reorder -Wno-sign-compare
endif

### Language #######################################################

LANG_FLAGS          = 
#-frepo  -fno-implicit-templates
COMPILER    		= -ansi  -use_readonly_const -ftemplate-depth-100

### Optimize / Debug ###############################################

ifeq ($(PRINT_INLINE), 1)
COMP_INLINE := 
endif

ifeq ($(DEBUG_VERSION), 0)
	COMP_OPTIMIZE    = -O2
	COMP_DEBUG       = 
else
	COMP_OPTIMIZE    =
	COMP_DEBUG       = -g -DOSG_DEBUG
endif

CCFLAGS_EXT_OPT := -O2
CCFLAGS_EXT_DBG := -g -DOSG_DEBUG

### Compiler Flags ################################################


DEFINES     = $(SOURCE_DEFINES) $(SYSTEM_DEFINES) $(DEP_PLATTFORMDEF)

# C Compiler Flags

NO_STD_INC     = -nostdinc
NO_STD_INC_DEP = -Y

CFLAGS   = $(WARNINGS) $(WARNINGS_C_OFF) -D__STDC__ $(DEFINES) 	\
		   $(COMPILER) $(COMP_OPTIMIZE) $(COMP_DEBUG) 

# CPP Compiler Flags

CCFLAGS   = $(WARNINGS)   $(WARNINGS_CPP_OFF) $(DEFINES)		\
		    $(COMPILER)   $(LANG_FLAGS)       $(COMP_OPTIMIZE) 	\
			$(COMP_DEBUG) 

CCFLAGS_EXT     := $(SOURCE_DEFINES) $(SYSTEM_DEFINES) $(DEP_PLATTFORMDEF) $(COMPILER) 

# Assembler Flags

ASFLAGS   = $(WARNINGS) $(WARNINGS_C_OFF) $(DEFINES) 	\
	 	    $(COMPILER) $(COMP_OPTIMIZE) $(COMP_DEBUG) 


# Linker Flags

ifeq ($(PRINT_INLINE), 1)
LINK_INLINE := 
endif

ifeq ($(DEBUG_VERSION), 0)
	LINK_OPTIMIZE    = -O2
	AR_FLAGS         = 
	LINK_DEBUG       = 
else
	LINK_OPTIMIZE    =
	LINK_DEBUG       = -g 
endif


LD_FLAGS += $(LINK_OPTIMIZE) $(LINK_DEBUG)


LD_FLAGS_EXT      =  
LD_FLAGS_EXT_OPT := -O2 
LD_FLAGS_EXT_DBG := -g 

ADD_OS_LIB := -L/usr/X11R6/lib 



### BASE DIRS #########################################################

INCL_$(OS_BASE) := $(INC_OPTION)"../Base" $(INCL_$(OS_BASE))
LIBS_$(OS_BASE) := -lpthread -ldl -lm 

INCLUDE_SYSTEM  := 
LINK_SYSTEM     := 

ADD_INCLUDE     := 
ADD_LINK        := 
ADD_LIBS        := 

INCLUDE_MPATROL := 
LINK_MPATROL    := 
LIB_MPATROL     := 

include /home/dave/maintaniedPackages/opensg/opensg-1.8.0alpha1/Builds/i686-pc-linux-gnu-g++/CommonPackages/commonSTL.mk


LINK_COMPILER   := 

ifneq ($(INCLUDE_SYSTEM),)
INCL_$(OS_BASE) := $(INCL_$(OS_BASE)) $(INC_OPTION)$(INCLUDE_SYSTEM)
endif

ifneq ($(LINK_SYSTEM),)
LIBPATHS_$(OS_BASE) := $(LIBPATH_OPTION)$(LINK_SYSTEM)   $(LIBPATHS_$(OS_BASE))
endif

ifneq ($(LINK_COMPILER),)
LIBPATHS_$(OS_BASE) := $(LIBPATH_OPTION)$(LINK_COMPILER) $(LIBPATHS_$(OS_BASE))
endif

ifneq ($(INCLUDE_MPATROL),)
INCL_$(OS_BASE) := $(INCL_$(OS_BASE)) $(INC_OPTION)$(INCLUDE_MPATROL)
endif

ifeq ($(IN_TEST_DIR),1)
ifneq ($(LINK_MPATROL),)
LIBPATHS_$(OS_BASE) := $(LIBPATH_OPTION)$(LINK_MPATROL) $(LIBPATHS_$(OS_BASE))
endif

ifneq ($(LB_MPATROL),)
LIBS_$(OS_BASE) := $(LIBLNK_OPTION)$(LIB_MPATROL) $(LIBS_$(OS_BASE))
endif
endif

#########################################################################
# Build include directive
#########################################################################

ifeq ($(OS_BASE), cygwin)
ifeq ($(OS_CMPLR),g++)
buildCIncPath      = $(INC_OPTION)$(1) 
else
buildCIncPath      = $(INC_OPTION)"$(shell cygpath -w $(1))"
endif
else
buildCIncPath      = $(INC_OPTION)$(1) 
endif

ifeq ($(OS_BASE), cygwin)
buildCLibPath      = $(LIBPATH_OPTION)"$(shell cygpath -w $(1))"
else
buildCLibPath      = $(LIBPATH_OPTION)$(1)
endif

ifneq ($(ADD_INCLUDE),)

ADD_INCLUDE := $(subst :, ,$(ADD_INCLUDE))

ADD_INCL_$(OS_BASE) := \
	$(foreach dir,$(ADD_INCLUDE),$(call buildCIncPath,$(dir)))

INCL_$(OS_BASE) := $(INCL_$(OS_BASE)) $(ADD_INCL_$(OS_BASE))

endif

ifneq ($(ADD_LINK),)

ADD_LINK := $(subst :, ,$(ADD_LINK))

ADD_LIBPATHS_$(OS_BASE) := \
	$(foreach dir,$(ADD_LINK),$(call buildCLibPath,$(dir)))

LIBPATHS_$(OS_BASE) := $(LIBPATHS_$(OS_BASE)) $(ADD_LIBPATHS_$(OS_BASE))

endif

ifneq ($(ADD_LIBS),)

ADD_LIBS := $(subst :, ,$(ADD_LIBS))

ifeq ($(OS_BASE),cygwin)
ADD_LIBS_$(OS_BASE) := $(foreach lib,$(ADD_LIBS),$(lib)$(LIB_SUFFIX))
else
ADD_LIBS_$(OS_BASE) := $(foreach lib,$(ADD_LIBS),$(LIBLNK_OPTION)$(lib))
endif

LIBS_$(OS_BASE) := $(ADD_LIBS_$(OS_BASE)) $(LIBS_$(OS_BASE))

endif

LIBS_$(OS_BASE) := $(LIBS_$(OS_BASE)) $(ADD_OS_LIB)
